@@ -20,7 +20,7 @@
  *
  */
 
-#define EC_SESSION_CUPS_OBJECT_PATH "/org/freedesktop/PrinterManager/SessionCups"
+#define EC_SESSION_CUPS_OBJECT_PATH "/com/redhat/PrinterManager/SessionCups"
 
 #include "config.h"
 #include "ec-cups-manager.h"
@@ -329,7 +329,7 @@ session_cupsd_message_handler (DBusConnection *connection,
 	rb_debug ("got message");
 
 	if (dbus_message_is_method_call (message,
-					 "org.freedesktop.PrinterManager",
+					 "com.redhat.PrinterManager",
 					 "getPassword")) {
 		DBusMessage *reply;
 		char *password;
@@ -362,7 +362,7 @@ session_cupsd_message_handler (DBusConnection *connection,
 		dbus_message_unref (reply);
 		return DBUS_HANDLER_RESULT_HANDLED;
 	} else if (dbus_message_is_method_call (message,
-						"org.freedesktop.PrinterManager",
+						"com.redhat.PrinterManager",
 						"getPort")) {
 		DBusMessage *reply;
 		guint port;
